ispman/lib/ISPMan ApacheMan.pm,1.67,1.68 ConfMan.pm,1.13,1.14 Config.pm,1.9,1.10 DNSMan.pm,1.30,1.31 DomainMan.pm,1.67,1.68 DomainServices.pm,1.8,1.9 HostMan.pm,1.16,1.17 LDAP.pm,1.79,1.80 Log.pm,1.5,1.6 MailGroupMan.pm,1.7,1.8 ResellerMan.pm,1.6,1.7 UserMan.pm,1.47,1.48 Utils.pm,1.21,1.22

Joerg Delker <[email protected]>
Newsgroups gmane.comp.isp.ispman.cvs
Message-ID <[email protected]>
Update of /cvsroot/ispman/ispman/lib/ISPMan
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv16384/lib/ISPMan

Modified Files:
	ApacheMan.pm ConfMan.pm Config.pm DNSMan.pm DomainMan.pm 
	DomainServices.pm HostMan.pm LDAP.pm Log.pm MailGroupMan.pm 
	ResellerMan.pm UserMan.pm Utils.pm 
Log Message:
applied spelling fix
(thanks to Mads Kiilerich)


Index: ResellerMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/ResellerMan.pm,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -d -r1.6 -r1.7
--- ResellerMan.pm	30 May 2004 23:35:37 -0000	1.6
+++ ResellerMan.pm	5 Jun 2004 12:45:24 -0000	1.7
@@ -180,7 +180,7 @@
     if ( $self->{'session'}->param("logintype") ne "admin" ) {
 
         #Only Admin can add resellers
-        print "Ouch!! Go away, I dont want to play with you no more.";
+        print "Ouch!! Go away, I don't want to play with you no more.";
         exit;
     }
     my $id = shift;

Index: ConfMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/ConfMan.pm,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -d -r1.13 -r1.14
--- ConfMan.pm	30 May 2004 23:35:37 -0000	1.13
+++ ConfMan.pm	5 Jun 2004 12:45:24 -0000	1.14
@@ -7,7 +7,7 @@
 
 =head1 SYNOPSIS
 
-   you dont have to  use this module directly.
+   you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
 

Index: HostMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/HostMan.pm,v
retrieving revision 1.16
retrieving revision 1.17
diff -u -d -r1.16 -r1.17
--- HostMan.pm	30 May 2004 23:35:37 -0000	1.16
+++ HostMan.pm	5 Jun 2004 12:45:24 -0000	1.17
@@ -6,7 +6,7 @@
 
 =head1 SYNOPSIS
 
-   you dont have to  use this module directly.
+   you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
 

Index: Log.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/Log.pm,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -d -r1.5 -r1.6
--- Log.pm	30 May 2004 23:35:37 -0000	1.5
+++ Log.pm	5 Jun 2004 12:45:24 -0000	1.6
@@ -130,7 +130,7 @@
 
 Possible values are between 0 and 3.
 
-0: Be quiet, dont log any thing (for production installations, speeds up the execution a lot)
+0: Be quiet, don't log any thing (for production installations, speeds up the execution a lot)
 
 1: Log user/vhost/domain addition/deletion and other general messages
 

Index: Config.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/Config.pm,v
retrieving revision 1.9
retrieving revision 1.10
diff -u -d -r1.9 -r1.10
--- Config.pm	30 May 2004 23:35:37 -0000	1.9
+++ Config.pm	5 Jun 2004 12:45:24 -0000	1.10
@@ -7,7 +7,7 @@
 
 =head1 SYNOPSIS
 
-   you dont have to  use this module directly.
+   you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
 

Index: LDAP.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/LDAP.pm,v
retrieving revision 1.79
retrieving revision 1.80
diff -u -d -r1.79 -r1.80
--- LDAP.pm	30 May 2004 23:35:37 -0000	1.79
+++ LDAP.pm	5 Jun 2004 12:45:24 -0000	1.80
@@ -555,7 +555,7 @@
     my $dn   = shift;
     my $data = shift;
 
-    # dont give error. just quit
+    # don't give error. just quit
     # ATIF FixME: 10 May 2002.
     # In future there should be some error reporting mech
     # sort of an array of error array etc.
@@ -569,7 +569,7 @@
     $entry->dn($dn);
 
     # get the first attrib name and val and
-    # add them in the entry if the dont exists.
+    # add them in the entry if the don't exists.
     my ( $attrib, $attribval ) = $dn =~ m/^(\w+)?\=([^,]*)/;
     $data->{$attrib} =
       $self->as_arrayref(
@@ -597,7 +597,7 @@
 
             # 2002-02-07.
             # ATIF: TEST ME
-            # dont add an attribute if it is blank
+            # don't add an attribute if it is blank
             # lets see if this breaks anything
             # $entry->add($_, "");
         }
@@ -695,7 +695,7 @@
     my $self = shift;
     my $dn   = shift;
 
-    # dont give error. just quit
+    # don't give error. just quit
     # ATIF FixME: 10 May 2002.
     # In future there should be some error reporting mech
     # sort of an array of error array etc.
@@ -843,7 +843,7 @@
     my @vals = ();
     for ( $dirty_entry->attributes() ) {
 
-        # dont bother if the attribute has no value
+        # don't bother if the attribute has no value
         if ( $dirty_entry->get_value($_) ) {
             @vals = ();
             undef @vals;

Index: DomainMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/DomainMan.pm,v
retrieving revision 1.67
retrieving revision 1.68
diff -u -d -r1.67 -r1.68
--- DomainMan.pm	30 May 2004 23:35:37 -0000	1.67
+++ DomainMan.pm	5 Jun 2004 12:45:24 -0000	1.68
@@ -402,7 +402,7 @@
         # Is this user Admin
         if ( $self->{'session'}->param("logintype") eq "admin" ) {
 
-            # Need atleast level 70 to be able to delete a domain
+            # Need at least level 70 to be able to delete a domain
             ###
             return unless $self->requiredAdminLevel(70);
         }
@@ -849,7 +849,7 @@
 all domains and caches the result. Every subsequent request gets a cached result. 
 (slow for diconnected access , extremely fast with mod_perl)
 
-You can pass optionally a positive value so that you dont get a cached result.
+You can pass optionally a positive value so that you don't get a cached result.
 
 I<EXAMPLE>
 

Index: ApacheMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/ApacheMan.pm,v
retrieving revision 1.67
retrieving revision 1.68
diff -u -d -r1.67 -r1.68
--- ApacheMan.pm	1 Jun 2004 00:03:47 -0000	1.67
+++ ApacheMan.pm	5 Jun 2004 12:45:24 -0000	1.68
@@ -6,7 +6,7 @@
 
 =head1 SYNOPSIS
 
-	dont use this module directly.
+	don't use this module directly.
 	use ISPMan instead.
 
 

Index: UserMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/UserMan.pm,v
retrieving revision 1.47
retrieving revision 1.48
diff -u -d -r1.47 -r1.48
--- UserMan.pm	30 May 2004 23:35:37 -0000	1.47
+++ UserMan.pm	5 Jun 2004 12:45:24 -0000	1.48
@@ -551,7 +551,7 @@
     my ( $userId, $domain ) = @_;
 
    # here is the logic to convert userName to user_domain_tld
-   # If you dont want this behaviour and just wasnt uid uncomment the next line;
+   # If you don't want this behaviour and just wasnt uid uncomment the next line;
    # return $userId;
 
     $domain =~ s/\./_/g;

Index: MailGroupMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/MailGroupMan.pm,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -d -r1.7 -r1.8
--- MailGroupMan.pm	30 May 2004 23:35:37 -0000	1.7
+++ MailGroupMan.pm	5 Jun 2004 12:45:24 -0000	1.8
@@ -6,7 +6,7 @@
 
 =head1 SYNOPSIS
 
-   you dont have to  use this module directly.
+   you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
 



-------------------------------------------------------
This SF.Net email is sponsored by the new InstallShield X.
From Windows to Linux, servers to mobile, InstallShield X is the one
installation-authoring solution that does it all. Learn more and
evaluate today! http://www.installshield.com/Dev2Dev/0504
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
Index: DomainServices.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/DomainServices.pm,v
retrieving revision 1.8
retrieving revision 1.9
diff -u -d -r1.8 -r1.9
--- DomainServices.pm	30 May 2004 23:35:37 -0000	1.8
+++ DomainServices.pm	5 Jun 2004 12:45:24 -0000	1.9
@@ -7,10 +7,10 @@
 =head1 SYNOPSIS
 
    In future there should be some functions to do with services and billing etc.
-   you dont have to  use this module directly.
+   you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
-   I am slowly removing dependency on CGI.pm, so that for the CLI we dont have to do hacks.
+   I am slowly removing dependency on CGI.pm, so that for the CLI we don't have to do hacks.
    
    
 
@@ -66,7 +66,7 @@
     my ($service) = @_;
 
 # Again, a util function to return the DN of the domain Service.
 # End-programmers dont need to build this DN.
 # This gives us the flexibility to change it in future without breaking the existing apps.
 
     # also reduces typo probability
@@ -66,7 +66,7 @@
 
 # Again, a util function to return the DN of the domain Service.
-# End-programmers dont need to build this DN.
+# End-programmers don't need to build this DN.
 # This gives us the flexibility to change it in future without breaking the existing apps.
 

Index: Utils.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/Utils.pm,v
retrieving revision 1.21
retrieving revision 1.22
diff -u -d -r1.21 -r1.22
--- Utils.pm	30 May 2004 23:35:37 -0000	1.21
+++ Utils.pm	5 Jun 2004 12:45:25 -0000	1.22
@@ -6,7 +6,7 @@
 
 =head1 SYNOPSIS
 
-   you dont have to  use this module directly.
+   you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
 
@@ -476,7 +476,7 @@
         }
         else {
 
             # dont add if $_ is undef
             push @l, $_ if $_;
         }
     }
@@ -476,7 +476,7 @@
         else {
 
-            # dont add if $_ is undef
+            # don't add if $_ is undef
             push @l, $_ if $_;
         }

Index: DNSMan.pm
===================================================================
RCS file: /cvsroot/ispman/ispman/lib/ISPMan/DNSMan.pm,v
retrieving revision 1.30
retrieving revision 1.31
diff -u -d -r1.30 -r1.31
--- DNSMan.pm	30 May 2004 23:35:37 -0000	1.30
+++ DNSMan.pm	5 Jun 2004 12:45:24 -0000	1.31
@@ -14,7 +14,7 @@
      ISPMan::DNSMan::NSrecords;
      ISPMan::DNSMan::CNAMES;
 
-   Normally you dont have to  use this module directly.
+   Normally you don't have to  use this module directly.
    Its used by other ISPMan modules.
    
 
@@ -180,7 +180,7 @@
         return;
 
         # we should not reach here.
         # I dont know why I added this code, but it was surely some work around,
         # removing temporarily
         # $extraHash->{$recordType}=$record;
         # $self->addData2Entry($dn, {"$recordType" => $record});
@@ -190,7 +190,7 @@
     }
     $self->touchSOA($domain)
       unless $recordType eq
-      "sOARecord";    # dont change SOA record, if we are actually changing SOA
+      "sOARecord";    # don't change SOA record, if we are actually changing SOA
     $self->modifyDnsProcess($domain);
 
 }
@@ -224,7 +224,7 @@
     }
     $self->touchSOA($domain)
       unless $recordType eq
-      "sOARecord";    # dont change SOA record, if we are actually changing SOA
+      "sOARecord";    # don't change SOA record, if we are actually changing SOA
     $self->modifyDnsProcess($domain);
 }
 
@@ -180,7 +180,7 @@
 
         # we should not reach here.
-        # I dont know why I added this code, but it was surely some work around,
+        # I don't know why I added this code, but it was surely some work around,
         # removing temporarily
         # $extraHash->{$recordType}=$record;
